[Qa-jenkins-scm] [jenkins.debian.net] 09/10: reproducible: rename 'sid' to 'unstable'

Holger Levsen holger at moszumanska.debian.org
Sat Mar 14 19:03:03 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit a8d1d541d1f5592f334294da14198c843446c111
Author: Holger Levsen <holger at layer-acht.org>
Date:   Sat Mar 14 19:45:07 2015 +0100

    reproducible: rename 'sid' to 'unstable'
---
 bin/reproducible_build.sh                      |  4 ++--
 bin/reproducible_common.py                     |  8 ++++----
 bin/reproducible_common.sh                     |  2 +-
 bin/reproducible_db_maintenance.py             |  8 ++++++++
 bin/reproducible_html_dd_list.sh               |  2 +-
 bin/reproducible_html_graphs.sh                | 16 ++++++++--------
 bin/reproducible_html_indexes.py               |  4 ++--
 bin/reproducible_html_notes.py                 |  4 ++--
 bin/reproducible_html_packages.py              |  2 +-
 bin/reproducible_html_repo_stats.sh            | 10 +++++-----
 bin/reproducible_maintainance.sh               |  2 +-
 bin/reproducible_setup_pbuilder.sh             |  4 ++--
 etc/apache2/sites-available/jenkins.debian.net | 26 +++++++++++++-------------
 job-cfg/reproducible.yaml                      | 24 ++++++++++++------------
 14 files changed, 62 insertions(+), 54 deletions(-)

diff --git a/bin/reproducible_build.sh b/bin/reproducible_build.sh
index 8551f1c..031b826 100755
--- a/bin/reproducible_build.sh
+++ b/bin/reproducible_build.sh
@@ -68,8 +68,8 @@ call_debbindiff() {
 		touch $DBDCHROOT_READLOCK
 	fi
 	echo | tee -a ${RBUILDLOG}
-	echo "$(date) - $(schroot --directory /tmp -c source:jenkins-reproducible-sid-debbindiff debbindiff -- --version 2>&1) will be used to compare the two builds now." | tee -a ${RBUILDLOG}
-	( timeout 15m schroot --directory $TMPDIR -c source:jenkins-reproducible-sid-debbindiff debbindiff -- --html ./${LOGFILE} ./b1/${SRCPACKAGE}_${EVERSION}_${ARCH}.changes ./b2/${SRCPACKAGE}_${EVERSION}_${ARCH}.changes ) 2>&1 >> ${RBUILDLOG}
+	echo "$(date) - $(schroot --directory /tmp -c source:jenkins-reproducible-unstable-debbindiff debbindiff -- --version 2>&1) will be used to compare the two builds now." | tee -a ${RBUILDLOG}
+	( timeout 15m schroot --directory $TMPDIR -c source:jenkins-reproducible-unstable-debbindiff debbindiff -- --html ./${LOGFILE} ./b1/${SRCPACKAGE}_${EVERSION}_${ARCH}.changes ./b2/${SRCPACKAGE}_${EVERSION}_${ARCH}.changes ) 2>&1 >> ${RBUILDLOG}
 	RESULT=$?
 	set +x
 	set -e
diff --git a/bin/reproducible_common.py b/bin/reproducible_common.py
index 7278089..49135b0 100755
--- a/bin/reproducible_common.py
+++ b/bin/reproducible_common.py
@@ -25,7 +25,7 @@ DEBUG = False
 QUIET = False
 
 # tested suites
-SUITES = ['testing', 'sid', 'experimental']
+SUITES = ['testing', 'unstable', 'experimental']
 # tested arches
 ARCHES = ['amd64']
 
@@ -195,12 +195,12 @@ def _gen_links(suite, arch):
     html = ''
     for link in links:
         if link[0] == 'pkg_sets' and suite and suite == 'experimental':
-            html += link[1].format(suite='sid', arch=arch) + '\n'
+            html += link[1].format(suite='unstable', arch=arch) + '\n'
             continue
         if suite:
             html += link[1].format(suite=suite, arch=arch) + '\n'
         if not suite:
-            html += link[1].format(suite='sid', arch=arch) + '\n'
+            html += link[1].format(suite='unstable', arch=arch) + '\n'
     if suite:  # suite stats
         html += '<li><a href="/' + suite + \
                 '/index_suite_stats.html">suite: ' + suite + '</a></li>'
@@ -364,7 +364,7 @@ def strip_epoch(version):
     except IndexError:
         return version
 
-def pkg_has_buildinfo(package, version=False, suite='sid', arch='amd64'):
+def pkg_has_buildinfo(package, version=False, suite='unstable', arch='amd64'):
     """
     if there is no version specified it will use the version listed in
     reproducible.db
diff --git a/bin/reproducible_common.sh b/bin/reproducible_common.sh
index cf86d64..a9ea3eb 100755
--- a/bin/reproducible_common.sh
+++ b/bin/reproducible_common.sh
@@ -40,7 +40,7 @@ DBDCHROOT_WRITELOCK=/var/lib/jenkins/reproducible-dbdchroot.writelock
 JENKINS_URL=${JENKINS_URL:0:-1}
 
 # tested suites
-SUITES="testing sid experimental"
+SUITES="testing unstable experimental"
 # tested arches
 ARCHES="amd64"
 
diff --git a/bin/reproducible_db_maintenance.py b/bin/reproducible_db_maintenance.py
index 6014c44..7c41d51 100755
--- a/bin/reproducible_db_maintenance.py
+++ b/bin/reproducible_db_maintenance.py
@@ -330,6 +330,14 @@ schema_updates = {
         'DROP TABLE stats_bugs',
         'ALTER TABLE stats_bugs_tmp RENAME TO stats_bugs',
         'INSERT INTO rb_schema VALUES ("8", "' + now + '")'],
+    9: [ # rename "sid" to "unstable"
+        'UPDATE sources SET suite = "unstable" WHERE suite = "sid"',
+        'UPDATE stats_build SET suite = "unstable" WHERE suite = "sid"',
+        'UPDATE stats_pkg_state SET suite = "unstable" WHERE suite = "sid"',
+        'UPDATE stats_builds_per_day SET suite = "unstable" WHERE suite = "sid"',
+        'UPDATE stats_builds_age SET suite = "unstable" WHERE suite = "sid"',
+        'UPDATE stats_meta_pkg_state SET suite = "unstable" WHERE suite = "sid"',
+        'INSERT INTO rb_schema VALUES ("9", "' + now + '")'],
 }
 
 
diff --git a/bin/reproducible_html_dd_list.sh b/bin/reproducible_html_dd_list.sh
index 024860a..fe0c39b 100755
--- a/bin/reproducible_html_dd_list.sh
+++ b/bin/reproducible_html_dd_list.sh
@@ -11,7 +11,7 @@ common_init "$@"
 # common code defining db access
 . /srv/jenkins/bin/reproducible_common.sh
 
-SUITE="sid"
+SUITE="unstable"
 ARCH="amd64"
 
 VIEW=dd-list
diff --git a/bin/reproducible_html_indexes.py b/bin/reproducible_html_indexes.py
index 39aeed4..e8ac6ae 100755
--- a/bin/reproducible_html_indexes.py
+++ b/bin/reproducible_html_indexes.py
@@ -25,8 +25,8 @@ Reference doc for the folowing lists:
     - `icon_link`: a link to hide below the icon
     - `query`: query to perform against the reproducible db to get the list of
       packages to show
-    - `text` a string.Template instance with $tot (total of packages listed)
-      and $percent (percentual on all sid packages)
+    - `text` a string. Template instance with $tot (total of packages listed)
+      and $percent (percentage of all packages)
     - `timely`: boolean value to enable to add $count and $count_total to the
       text, where:
       * $percent becomes count/count_total
diff --git a/bin/reproducible_html_notes.py b/bin/reproducible_html_notes.py
index 64fee60..fc906b7 100755
--- a/bin/reproducible_html_notes.py
+++ b/bin/reproducible_html_notes.py
@@ -248,7 +248,7 @@ def gen_html_issue(issue):
     # add affected packages:
     affected = ''
     try:
-        suite = 'sid'
+        suite = 'unstable'
         arch = 'amd64'
         for status in ['unreproducible', 'FTBFS', 'not for us', 'blacklisted', 'reproducible']:
             pkgs = [x[0] for x in all_pkgs if x[1] == status and x[2] == suite and x[3] == arch and x[0] in issues_count[issue]]
@@ -379,7 +379,7 @@ def index_issues(issues):
 
 def index_notes(notes, bugs):
     log.debug('Building the index_notes page...')
-    suite = 'sid'
+    suite = 'unstable'
     arch = 'amd64'
     with_notes = [x for x in all_pkgs if x[2] == suite and x[3] == arch and x[0] in notes]
     html = '\n<p>There are ' + str(len(notes)) + ' packages with notes.</p>\n'
diff --git a/bin/reproducible_html_packages.py b/bin/reproducible_html_packages.py
index 22decc6..3c327fd 100755
--- a/bin/reproducible_html_packages.py
+++ b/bin/reproducible_html_packages.py
@@ -219,7 +219,7 @@ def gen_packages_html(packages, suite=None, arch=None, no_clean=False, nocheck=F
     if not no_clean:
         purge_old_pages() # housekeep is always good
 
-def gen_all_rb_pkg_pages(suite='sid', arch='amd64', no_clean=False):
+def gen_all_rb_pkg_pages(suite='unstable', arch='amd64', no_clean=False):
     query = 'SELECT name FROM sources WHERE suite="%s" AND architecture="%s"' % (suite, arch)
     rows = query_db(query)
     pkgs = [str(i[0]) for i in rows]
diff --git a/bin/reproducible_html_repo_stats.sh b/bin/reproducible_html_repo_stats.sh
index edaef67..3591b73 100755
--- a/bin/reproducible_html_repo_stats.sh
+++ b/bin/reproducible_html_repo_stats.sh
@@ -10,8 +10,8 @@ common_init "$@"
 # common code defining db access
 . /srv/jenkins/bin/reproducible_common.sh
 
-SUITE="sid"	# for links in page
-ARCH="amd64"	# same
+SUITE="unstable"	# for links in page
+ARCH="amd64"		# same
 
 VIEW=repo_stats
 PAGE=index_${VIEW}.html
@@ -20,11 +20,11 @@ TMP2FILE=$(mktemp)
 
 echo "$(date) - starting to write $PAGE page."
 write_page_header $VIEW "Comparison between the reproducible builds apt repository and regular Debian suites"
-write_page "<p>These source packages are different from sid in our apt repository on alioth. They are available for <a href=\"https://wiki.debian.org/ReproducibleBuilds/ExperimentalToolchain#Usage_example\">testing using these sources.lists</a> entries:<pre>"
+write_page "<p>These source packages are different from unstable in our apt repository on alioth. They are available for <a href=\"https://wiki.debian.org/ReproducibleBuilds/ExperimentalToolchain#Usage_example\">testing using these sources.lists</a> entries:<pre>"
 write_page "deb http://reproducible.alioth.debian.org/debian/ ./"
 write_page "deb-src http://reproducible.alioth.debian.org/debian/ ./"
 write_page "</pre></p>"
-write_page "<p><table><tr><th>source package</th><th>old versions in our repo<br />(needed for reproducing old builds)</th><th>version in our repo</th><th>version in 'testing'</th><th>version in 'sid'</th><th>version in 'experimental'</th></tr>"
+write_page "<p><table><tr><th>source package</th><th>old versions in our repo<br />(needed for reproducing old builds)</th><th>version in our repo</th><th>version in 'testing'</th><th>version in 'unstable'</th><th>version in 'experimental'</th></tr>"
 
 curl http://reproducible.alioth.debian.org/debian/Sources > $TMPFILE
 SOURCES=$(grep-dctrl -n -s Package -r -FPackage . $TMPFILE | sort -u)
@@ -50,7 +50,7 @@ for PKG in $SOURCES ; do
 			BET=${VERSION}
 		fi
 	done
-	SID=$(rmadison -s sid $PKG | cut -d "|" -f2|xargs echo)
+	SID=$(rmadison -s unstable $PKG | cut -d "|" -f2|xargs echo)
 	for VERSION in ${VERSIONS} ; do
 		if [ "${VERSION}" != "$BET" ] ; then
 			CRUFT="$CRUFT ${VERSION}"
diff --git a/bin/reproducible_maintainance.sh b/bin/reproducible_maintainance.sh
index 397b13a..1fd5228 100755
--- a/bin/reproducible_maintainance.sh
+++ b/bin/reproducible_maintainance.sh
@@ -155,7 +155,7 @@ if grep -q '|' $PACKAGES ; then
 fi
 rm $PACKAGES
 
-# find packages which have been removed from sid
+# find packages which have been removed from unstable
 # commented out for now. This can't be done using the database anymore
 QUERY="SELECT source_packages.name FROM source_packages
 		WHERE source_packages.name NOT IN
diff --git a/bin/reproducible_setup_pbuilder.sh b/bin/reproducible_setup_pbuilder.sh
index cfc0902..189ebeb 100755
--- a/bin/reproducible_setup_pbuilder.sh
+++ b/bin/reproducible_setup_pbuilder.sh
@@ -12,7 +12,7 @@ common_init "$@"
 
 # support different suites
 if [ -z "$1" ] ; then
-	SUITE="sid"
+	SUITE="unstable"
 else
 	SUITE="$1"
 fi
@@ -84,7 +84,7 @@ setup_pbuilder() {
 	TMPFILE=$(mktemp)
 	LOG=$(mktemp)
 	if [ "$SUITE" = "experimental" ] ; then
-		SUITE=sid
+		SUITE=unstable
 		echo "echo 'deb $MIRROR experimental main' > /etc/apt/sources.list.d/experimental.list" > ${TMPFILE}
 		echo "echo 'deb-src $MIRROR experimental main' >> /etc/apt/sources.list.d/experimental.list" >> ${TMPFILE}
 	fi
diff --git a/etc/apache2/sites-available/jenkins.debian.net b/etc/apache2/sites-available/jenkins.debian.net
index bd2f2e8..db8f47f 100644
--- a/etc/apache2/sites-available/jenkins.debian.net
+++ b/etc/apache2/sites-available/jenkins.debian.net
@@ -162,33 +162,33 @@ Use common-debian-service-https-redirect reproducible.debian.net
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
 	RewriteCond %{REQUEST_FILENAME} !-d
-	RewriteCond /var/lib/jenkins/userContent/rb-pkg/sid/amd64/$1.html -f
-	RewriteRule ^/([a-z0-9.+-]+) /rb-pkg/sid/amd64/$1.html [R=302,L]
+	RewriteCond /var/lib/jenkins/userContent/rb-pkg/unstable/amd64/$1.html -f
+	RewriteRule ^/([a-z0-9.+-]+) /rb-pkg/unstable/amd64/$1.html [R=302,L]
 
 	# redirect rb.d.n/rb-pkg/$PKG.html → rb.d.n/rb-pkg/$suite/$arch/$PKG.html
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
 	RewriteCond %{REQUEST_FILENAME} !-d
-	RewriteCond /var/lib/jenkins/userContent/rb-pkg/sid/amd64/$1 -f
-	RewriteRule ^/rb-pkg/([a-z0-9.+-]+) /rb-pkg/sid/amd64/$1 [R=301,L]
+	RewriteCond /var/lib/jenkins/userContent/rb-pkg/unstable/amd64/$1 -f
+	RewriteRule ^/rb-pkg/([a-z0-9.+-]+) /rb-pkg/unstable/amd64/$1 [R=301,L]
 	# the same for /dbd/
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
 	RewriteCond %{REQUEST_FILENAME} !-d
-	RewriteCond /var/lib/jenkins/userContent/dbd/sid/amd64/$1 -f
-	RewriteRule ^/dbd/([a-z0-9.+-_]+) /dbd/sid/amd64/$1 [R=301,L]
+	RewriteCond /var/lib/jenkins/userContent/dbd/unstable/amd64/$1 -f
+	RewriteRule ^/dbd/([a-z0-9.+-_]+) /dbd/unstable/amd64/$1 [R=301,L]
 	# the same for /rbuild/
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
 	RewriteCond %{REQUEST_FILENAME} !-d
-	RewriteCond /var/lib/jenkins/userContent/rbuild/sid/amd64/$1 -f
-	RewriteRule ^/rbuild/([a-z0-9.+-_]+) /rbuild/sid/amd64/$1 [R=301,L]
+	RewriteCond /var/lib/jenkins/userContent/rbuild/unstable/amd64/$1 -f
+	RewriteRule ^/rbuild/([a-z0-9.+-_]+) /rbuild/unstable/amd64/$1 [R=301,L]
 	# the same for /buildinfo/
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
 	RewriteCond %{REQUEST_FILENAME} !-d
-	RewriteCond /var/lib/jenkins/userContent/buildinfo/sid/amd64/$1 -f
-	RewriteRule ^/buildinfo/([a-z0-9.+-_]+) /buildinfo/sid/amd64/$1 [R=301,L]
+	RewriteCond /var/lib/jenkins/userContent/buildinfo/unstable/amd64/$1 -f
+	RewriteRule ^/buildinfo/([a-z0-9.+-_]+) /buildinfo/unstable/amd64/$1 [R=301,L]
 	# redirect some rb.d.n/index_*.html to the suite/arch relative one
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
 	RewriteCond %{REQUEST_FILENAME} !-f
@@ -202,12 +202,12 @@ Use common-debian-service-https-redirect reproducible.debian.net
 	RewriteCond %{REQUEST_URI} ^/index_last_24h.html$ [or]
 	RewriteCond %{REQUEST_URI} ^/index_last_48h.html$ [or]
 	RewriteCond %{REQUEST_URI} ^/index_all_abc.html$
-	RewriteRule ^/?(.+) /sid/amd64/$1 [R=301,L]
+	RewriteRule ^/?(.+) /unstable/amd64/$1 [R=301,L]
 
-	# redirect (/testing|sid|/experimental) to (/testing|/sid|/experimental)/index_suite_stats.html
+	# redirect (/testing|unstable|/experimental) to (/testing|/unstable|/experimental)/index_suite_stats.html
 	# note: the missing slash in the RewriteRule is wanted to avoid a double slash
 	RewriteCond %{HTTP_HOST} reproducible\.debian\.net
-	RewriteCond %{REQUEST_URI} ^/(testing|sid|experimental)/$
+	RewriteCond %{REQUEST_URI} ^/(testing|unstable|experimental)/$
 	RewriteRule ^/(.*) /$1index_suite_stats.html [R,L]
 
 </VirtualHost>
diff --git a/job-cfg/reproducible.yaml b/job-cfg/reproducible.yaml
index fdcb581..a2c4680 100644
--- a/job-cfg/reproducible.yaml
+++ b/job-cfg/reproducible.yaml
@@ -125,7 +125,7 @@
 
 - job-template:
     defaults: reproducible
-    name: '{name}_setup_pbuilder_sid'
+    name: '{name}_setup_pbuilder_unstable'
 
 - job-template:
     defaults: reproducible
@@ -137,11 +137,11 @@
 
 - job-template:
     defaults: reproducible
-    name: '{name}_setup_schroot_sid_debbindiff'
+    name: '{name}_setup_schroot_unstable_debbindiff'
 
 - job-template:
     defaults: reproducible
-    name: '{name}_setup_schroot_sid'
+    name: '{name}_setup_schroot_unstable'
 
 - job-template:
     defaults: reproducible
@@ -219,25 +219,25 @@
             my_timed: '23 0,4,8,12,16,20 * * *'
             my_shell: '/srv/jenkins/bin/reproducible_setup_pbuilder.sh testing'
             my_recipients: 'jenkins+debian-reproducible qa-jenkins-scm at lists.alioth.debian.org'
-        - '{name}_setup_pbuilder_sid':
-            my_description: 'Setup and update pbuilder for reproducible builds of packages from sid as described in https://wiki.debian.org/ReproducibleBuilds#Usage_example'
+        - '{name}_setup_pbuilder_unstable':
+            my_description: 'Setup and update pbuilder for reproducible builds of packages from unstable as described in https://wiki.debian.org/ReproducibleBuilds#Usage_example'
             my_timed: '23 0,4,8,12,16,20 * * *'
-            my_shell: '/srv/jenkins/bin/reproducible_setup_pbuilder.sh sid'
+            my_shell: '/srv/jenkins/bin/reproducible_setup_pbuilder.sh unstable'
             my_recipients: 'jenkins+debian-reproducible qa-jenkins-scm at lists.alioth.debian.org'
         - '{name}_setup_pbuilder_experimental':
             my_description: 'Setup and update pbuilder for reproducible builds of packages from experimental as described in https://wiki.debian.org/ReproducibleBuilds#Usage_example'
             my_timed: '23 0,4,8,12,16,20 * * *'
             my_shell: '/srv/jenkins/bin/reproducible_setup_pbuilder.sh experimental'
             my_recipients: 'jenkins+debian-reproducible qa-jenkins-scm at lists.alioth.debian.org'
-        - '{name}_setup_schroot_sid_debbindiff':
-            my_description: 'Setup schroot for running debbindiff in a sid environment (this is needed to be able to correctly investigate haskell binaries...)'
+        - '{name}_setup_schroot_unstable_debbindiff':
+            my_description: 'Setup schroot for running debbindiff in a unstable environment (this is needed to be able to correctly investigate haskell binaries...)'
             my_timed: '23 0 * * *'
-            my_shell: '/srv/jenkins/bin/reproducible_setup_schroot.sh reproducible-sid-debbindiff sid debbindiff'
+            my_shell: '/srv/jenkins/bin/reproducible_setup_schroot.sh reproducible-unstable-debbindiff unstable debbindiff'
             my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
-        - '{name}_setup_schroot_sid':
-            my_description: 'Setup sid schroot for fetching source packages for the builder jobs.'
+        - '{name}_setup_schroot_unstable':
+            my_description: 'Setup unstable schroot for fetching source packages for the builder jobs.'
             my_timed: '23 1 * * *'
-            my_shell: '/srv/jenkins/bin/schroot-create.sh reproducible-sid sid reproducible'
+            my_shell: '/srv/jenkins/bin/schroot-create.sh reproducible-unstable unstable reproducible'
             my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
         - '{name}_setup_schroot_testing':
             my_description: 'Setup testing schroot for fetching source packages for the builder jobs.'

diff --git a/bin/reproducible_html_graphs.sh b/bin/reproducible_html_graphs.sh
index 6925617..e4bcc17 100755
--- a/bin/reproducible_html_graphs.sh
+++ b/bin/reproducible_html_graphs.sh
@@ -281,19 +281,19 @@ create_png_from_table() {
 	if [ $1 -eq 1 ] ; then
 		# not sure if it's worth to generate the following query...
 		sqlite3 -init ${INIT} --nullvalue 0 -csv ${PACKAGES_DB} "select s.datum,
-			 s.reproducible as 'reproducible_sid',
+			 s.reproducible as 'reproducible_unstable',
 			 COALESCE((SELECT e.reproducible FROM stats_builds_per_day AS e where s.datum=e.datum and suite='experimental'),0) as 'reproducible_experimental', 
 			 COALESCE((SELECT e.reproducible FROM stats_builds_per_day AS e where s.datum=e.datum and suite='testing'),0) as 'reproducible_testing',
-			 s.unreproducible as 'unreproducible_sid',
+			 s.unreproducible as 'unreproducible_unstable',
 			 (SELECT e.unreproducible FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='experimental') AS unreproducible_experimental,
 			 (SELECT e.unreproducible FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='testing') AS unreproducible_testing,
-			 s.FTBFS as 'FTBFS_sid',
+			 s.FTBFS as 'FTBFS_unstable',
 			 (SELECT e.FTBFS FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='experimental') AS FTBFS_experimental,
 			 (SELECT e.FTBFS FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='testing') AS FTBFS_testing,
-			 s.other as 'other_sid',
+			 s.other as 'other_unstable',
 			 (SELECT e.other FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='experimental') AS other_experimental,
 			 (SELECT e.other FROM stats_builds_per_day e WHERE s.datum=e.datum AND suite='testing') AS other_testing
-			 FROM stats_builds_per_day AS s WHERE s.suite='sid' GROUP BY s.datum" >> ${TABLE[$1]}.csv
+			 FROM stats_builds_per_day AS s WHERE s.suite='unstable' GROUP BY s.datum" >> ${TABLE[$1]}.csv
 	elif [ $1 -eq 2 ] ; then
 		sqlite3 -init ${INIT} -csv ${PACKAGES_DB} "SELECT datum, ((oldest_reproducible + oldest_unreproducible + oldest_FTBFS)/3) FROM ${TABLE[$1]} ${WHERE_EXTRA} ORDER BY datum" >> ${TABLE[$1]}.csv
 	elif [ $1 -eq 7 ] ; then
@@ -486,8 +486,8 @@ create_main_stats_page() {
 	write_page "</p><p>"
 	# write meta pkg graphs per suite
 	for SUITE in $SUITES ; do
-		if [ "$SUITE" != "sid" ] ; then
-			# only show pkg sets from sid for now
+		if [ "$SUITE" != "unstable" ] ; then
+			# only show pkg sets from unstable for now
 			continue
 		fi
 		for i in $(seq 1 ${#META_PKGSET[@]}) ; do
@@ -544,7 +544,7 @@ create_main_stats_page() {
 #
 # main
 #
-SUITE="sid"
+SUITE="unstable"
 update_bug_stats
 update_notes_stats
 create_main_stats_page
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list